@@ -10,8 +10,8 @@ from urllib.parse import unquote
 from bs4 import BeautifulSoup
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.utils import get_buffer_mime_type
 from komikku.utils import is_number
 
@@ -26,8 +26,7 @@ class Flamescans(Server):
     search_url = base_url + '/browse'
     manga_url = base_url + '/series/{0}'
     chapter_url = base_url + '/series/{0}/{1}'
-    cover_url = base_url + '/_next/image?url=https%3A%2F%2Fcdn.flamecomics.xyz%2Fseries%2F{0}%2F{1}%3F{2}&w=720&q=100'
-
+    cover_url = base_url + '/_next/image?url=https%3A%2F%2Fcdn.flamecomics.xyz%2Fuploads%2Fimages%2Fseries%2F{0}%2F{1}%3F%2F{2}&w=720&q=100'
     long_strip_genres = ['Manhua', 'Manhwa']
 
     filters = [
@@ -133,7 +132,7 @@ class Flamescans(Server):
                 data['genres'].append(serie_data['status'])
 
             if serie_data.get('description'):
-                data['synopsis'] = serie_data['description']
+                data['synopsis'] = BeautifulSoup(serie_data['description'], 'lxml').text
 
             # Chapters
             chapters_data = json.loads(script)['props']['pageProps']['chapters']
@@ -151,7 +150,7 @@ class Flamescans(Server):
                     slug=chapter['token'],
                     title=title,
                     num=num if is_number(num) else None,
-                    date=datetime.date.fromtimestamp(chapter['unix_timestamp']),
+                    date=datetime.date.fromtimestamp(chapter['release_date']),
                 ))
 
         if not found:
