@@ -4,8 +4,8 @@
 
 import requests
 
+from komikku.consts import USER_AGENT
 from komikku.servers import Server
-from komikku.servers import USER_AGENT
 from komikku.servers.utils import convert_date_string
 from komikku.utils import get_buffer_mime_type
 
@@ -120,7 +120,7 @@ class Honeymanga(Server):
                 title=title,
                 num=chapter['chapterNum'],
                 num_volume=chapter['volume'],
-                date=convert_date_string(chapter["lastUpdated"].split('T')[0], format='%Y-%m-%d'),
+                date=convert_date_string(chapter['lastUpdated'].split('T')[0], format='%Y-%m-%d'),
             ))
 
         if resp_data['cursorNext']:
