@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 import re
@@ -11,10 +11,12 @@ class Manga3asq(Madara2):
     id = 'manga3asq'
     name = 'مانجا العاشق'
     lang = 'ar'
+    status = 'disabled'
 
     date_format = '%Y \u060c%B %-d'
 
     base_url = 'https://3asq.org'
+    logo_url = base_url + '/wp-content/uploads/2021/06/cropped-ICON-32x32.png'
     chapters_url = base_url + '/manga/{0}/ajax/chapters/'
     chapter_url = base_url + '/manga/{0}/{1}/'
 
