@@ -1,5 +1,5 @@
-# Copyright (C) 2019-2024 Valéry Febvre
-# SPDX-License-Identifier: GPL-3.0-only or GPL-3.0-or-later
+# SPDX-FileCopyrightText: 2019-2025 Valéry Febvre
+# SPDX-License-Identifier: GPL-3.0-or-later
 # Author: Valéry Febvre <vfebvre@easter-eggs.com>
 
 from komikku.servers.multi.wpcomics import WPComics
@@ -11,7 +11,10 @@ class Xoxocomics(WPComics):
     lang = 'en'
     is_nsfw = True
 
+    has_cf = True
+
     base_url = 'https://xoxocomic.com'
+    logo_url = base_url + '/images/sites/favicon.png'
     search_url = base_url + '/search-comic'
     latest_updates_url = base_url + '/comic-update'
     most_populars_url = base_url + '/popular-comic'
